/****Begin 08月01日 詹叶俊 新增 job定时任务相关表****/

DROP TABLE IF EXISTS `qrtz_job_details`;
CREATE TABLE `qrtz_job_details` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `job_name` VARCHAR(200) NOT NULL COMMENT '任务名称',
  `job_group` VARCHAR(200) NOT NULL COMMENT '任务组名',
  `description` VARCHAR(250) DEFAULT NULL COMMENT '相关介绍',
  `job_class_name` VARCHAR(250) NOT NULL COMMENT '执行任务类名称',
  `is_durable` VARCHAR(1) NOT NULL COMMENT '是否持久化',
  `is_nonconcurrent` VARCHAR(1) NOT NULL COMMENT '是否并发',
  `is_update_data` VARCHAR(1) NOT NULL COMMENT '是否更新数据',
  `requests_recovery` VARCHAR(1) NOT NULL COMMENT '是否接受恢复执行',
  `job_data` BLOB COMMENT '存放持久化job对象',
  PRIMARY KEY (`sched_name`,`job_name`,`job_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='任务详细信息表';

DROP TABLE IF EXISTS `qrtz_triggers`;
CREATE TABLE `qrtz_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT '触发器的名字',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT '触发器所属组的名字',
  `job_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_job_details表job_name的外键',
  `job_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_job_details表job_group的外键',
  `description` VARCHAR(250) DEFAULT NULL COMMENT '相关介绍',
  `next_fire_time` BIGINT(13) DEFAULT NULL COMMENT '上一次触发时间（毫秒）',
  `prev_fire_time` BIGINT(13) DEFAULT NULL COMMENT '下一次触发时间（默认为-1表示不触发）',
  `priority` INT(11) DEFAULT NULL COMMENT '优先级',
  `trigger_state` VARCHAR(16) NOT NULL COMMENT '触发器状态',
  `trigger_type` VARCHAR(8) NOT NULL COMMENT '触发器的类型',
  `start_time` BIGINT(13) NOT NULL COMMENT '开始时间',
  `end_time` BIGINT(13) DEFAULT NULL COMMENT '结束时间',
  `calendar_name` VARCHAR(200) DEFAULT NULL COMMENT '日程表名称',
  `misfire_instr` SMALLINT(2) DEFAULT NULL COMMENT '补偿执行的策略',
  `job_data` BLOB COMMENT '存放持久化job对象',
  PRIMARY KEY (`sched_name`,`trigger_name`,`trigger_group`),
  KEY `sched_name` (`sched_name`,`job_name`,`job_group`),
  CONSTRAINT `qrtz_triggers_ibfk_1` FOREIGN KEY (`sched_name`, `job_name`, `job_group`) REFERENCES `qrtz_job_details` (`sched_name`, `job_name`, `job_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='触发器详细信息表';

DROP TABLE IF EXISTS `qrtz_blob_triggers`;
CREATE TABLE `qrtz_blob_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_name的外键',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  `blob_data` BLOB COMMENT '存放持久化Trigger对象',
  PRIMARY KEY (`sched_name`,`trigger_name`,`trigger_group`),
  CONSTRAINT `qrtz_blob_triggers_ibfk_1` FOREIGN KEY (`sched_name`, `trigger_name`, `trigger_group`) REFERENCES `qrtz_triggers` (`sched_name`, `trigger_name`, `trigger_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='Blob类型的触发器表';

DROP TABLE IF EXISTS `qrtz_calendars`;
CREATE TABLE `qrtz_calendars` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `calendar_name` VARCHAR(200) NOT NULL COMMENT '日历名称',
  `calendar` BLOB NOT NULL COMMENT '存放持久化calendar对象',
  PRIMARY KEY (`sched_name`,`calendar_name`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='日历信息表';

DROP TABLE IF EXISTS `qrtz_cron_triggers`;
CREATE TABLE `qrtz_cron_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_name的外键',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  `cron_expression` VARCHAR(200) NOT NULL COMMENT 'cron表达式',
  `time_zone_id` VARCHAR(80) DEFAULT NULL COMMENT '时区',
  PRIMARY KEY (`sched_name`,`trigger_name`,`trigger_group`),
  CONSTRAINT `qrtz_cron_triggers_ibfk_1` FOREIGN KEY (`sched_name`, `trigger_name`, `trigger_group`) REFERENCES `qrtz_triggers` (`sched_name`, `trigger_name`, `trigger_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='Cron类型的触发器表';

DROP TABLE IF EXISTS `qrtz_fired_triggers`;
CREATE TABLE `qrtz_fired_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `entry_id` VARCHAR(95) NOT NULL COMMENT '调度器实例id',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_name的外键',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  `instance_name` VARCHAR(200) NOT NULL COMMENT '调度器实例名',
  `fired_time` BIGINT(13) NOT NULL COMMENT '触发的时间',
  `sched_time` BIGINT(13) NOT NULL COMMENT '定时器制定的时间',
  `priority` INT(11) NOT NULL COMMENT '优先级',
  `state` VARCHAR(16) NOT NULL COMMENT '状态',
  `job_name` VARCHAR(200) DEFAULT NULL COMMENT '任务名称',
  `job_group` VARCHAR(200) DEFAULT NULL COMMENT '任务组名',
  `is_nonconcurrent` VARCHAR(1) DEFAULT NULL COMMENT '是否并发',
  `requests_recovery` VARCHAR(1) DEFAULT NULL COMMENT '是否接受恢复执行',
  PRIMARY KEY (`sched_name`,`entry_id`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='已触发的触发器表';

DROP TABLE IF EXISTS `qrtz_locks`;
CREATE TABLE `qrtz_locks` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `lock_name` VARCHAR(40) NOT NULL COMMENT '悲观锁名称',
  PRIMARY KEY (`sched_name`,`lock_name`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='存储的悲观锁信息表';

DROP TABLE IF EXISTS `qrtz_paused_trigger_grps`;
CREATE TABLE `qrtz_paused_trigger_grps` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  PRIMARY KEY (`sched_name`,`trigger_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='暂停的触发器表';

DROP TABLE IF EXISTS `qrtz_scheduler_state`;
CREATE TABLE `qrtz_scheduler_state` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `instance_name` VARCHAR(200) NOT NULL COMMENT '实例名称',
  `last_checkin_time` BIGINT(13) NOT NULL COMMENT '上次检查时间',
  `checkin_interval` BIGINT(13) NOT NULL COMMENT '检查间隔时间',
  PRIMARY KEY (`sched_name`,`instance_name`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='调度器状态表';

DROP TABLE IF EXISTS `qrtz_simple_triggers`;
CREATE TABLE `qrtz_simple_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_name的外键',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  `repeat_count` BIGINT(7) NOT NULL COMMENT '重复的次数统计',
  `repeat_interval` BIGINT(12) NOT NULL COMMENT '重复的间隔时间',
  `times_triggered` BIGINT(10) NOT NULL COMMENT '已经触发的次数',
  PRIMARY KEY (`sched_name`,`trigger_name`,`trigger_group`),
  CONSTRAINT `qrtz_simple_triggers_ibfk_1` FOREIGN KEY (`sched_name`, `trigger_name`, `trigger_group`) REFERENCES `qrtz_triggers` (`sched_name`, `trigger_name`, `trigger_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='简单触发器的信息表';

DROP TABLE IF EXISTS `qrtz_simprop_triggers`;
CREATE TABLE `qrtz_simprop_triggers` (
  `sched_name` VARCHAR(120) NOT NULL COMMENT '调度名称',
  `trigger_name` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_name的外键',
  `trigger_group` VARCHAR(200) NOT NULL COMMENT 'qrtz_triggers表trigger_group的外键',
  `str_prop_1` VARCHAR(512) DEFAULT NULL COMMENT 'String类型的trigger的第一个参数',
  `str_prop_2` VARCHAR(512) DEFAULT NULL COMMENT 'String类型的trigger的第二个参数',
  `str_prop_3` VARCHAR(512) DEFAULT NULL COMMENT 'String类型的trigger的第三个参数',
  `int_prop_1` INT(11) DEFAULT NULL COMMENT 'int类型的trigger的第一个参数',
  `int_prop_2` INT(11) DEFAULT NULL COMMENT 'int类型的trigger的第二个参数',
  `long_prop_1` BIGINT(20) DEFAULT NULL COMMENT 'long类型的trigger的第一个参数',
  `long_prop_2` BIGINT(20) DEFAULT NULL COMMENT 'long类型的trigger的第二个参数',
  `dec_prop_1` DECIMAL(13,4) DEFAULT NULL COMMENT 'decimal类型的trigger的第一个参数',
  `dec_prop_2` DECIMAL(13,4) DEFAULT NULL COMMENT 'decimal类型的trigger的第二个参数',
  `bool_prop_1` VARCHAR(1) DEFAULT NULL COMMENT 'Boolean类型的trigger的第一个参数',
  `bool_prop_2` VARCHAR(1) DEFAULT NULL COMMENT 'Boolean类型的trigger的第二个参数',
  PRIMARY KEY (`sched_name`,`trigger_name`,`trigger_group`),
  CONSTRAINT `qrtz_simprop_triggers_ibfk_1` FOREIGN KEY (`sched_name`, `trigger_name`, `trigger_group`) REFERENCES `qrtz_triggers` (`sched_name`, `trigger_name`, `trigger_group`)
) ENGINE=INNODB DEFAULT CHARSET=armscii8 COMMENT='同步机制的行锁表';

/****End 08月01日 詹叶俊 新增 job定时任务相关表****/


